const util = require('util');
const fs = require('fs');
const childProcess = require('child_process');

const exec = util.promisify(childProcess.exec);

class OnePassword {
	constructor() {}

	async signin() {
		return new Promise((resolve, reject) => {
			let data = '';
			var p = childProcess.spawn('op', ['signin'], { stdio: [fs.openSync('/dev/tty'), 'pipe', 'inherit'] });
			p.stdout.setEncoding('utf-8');
			p.stdout.on('data', function(chunk) {
				data += chunk;
			});

			p.on('close', async function(code) {
				var m = data.match('export (?<key>OP_SESSION_.*)="(?<val>[^"]+)"');
				if (m) {
					process.env[m.groups.key] = m.groups.val;
				}
				resolve(data);
			});
			p.on('error', function(err) {
				reject(err);
			});
		});

	}

	async get(key) {
		return new Promise((resolve, reject) => {
			let data = '';
			var p = childProcess.spawn('op', ['get', 'item', key], { stdio: ['inherit', 'pipe', 'inherit'] });
			p.stdout.setEncoding('utf-8');
			p.stdout.on('data', function(chunk) {
				data += chunk;
			});

			p.on('close', async function(code) {
				const item = JSON.parse(data);
				const result = {};

				item.details.sections.forEach(section => {
				    section.fields.forEach(field=>{
				        result[field.t] = field.value;
				    });
				});

				resolve(result);
			});
			p.on('error', function(err) {
				reject(err);
			});
		});
	}
}

module.exports = OnePassword;
